@@ -1,10 +1,10 @@
-#define ARMA_DONT_PRINT_ERRORS
+#define ARMA_WARN_LEVEL 0
 
 #include <iostream>
 #include <RcppArmadillo.h>
 #include <Rcpp.h>
-#include <boost/math/special_functions/bessel.hpp>
-#include <boost/math/special_functions/gamma.hpp>
+//#include <boost/math/special_functions/bessel.hpp>
+//#include <boost/math/special_functions/gamma.hpp>
 
 using namespace Rcpp;
 using namespace arma;
